@@ -1,6 +1,6 @@
-from birdbrain_exception import BirdbrainException
-from birdbrain_hummingbird import BirdbrainHummingbird
-from birdbrain_microbit import BirdbrainMicrobit
+from birdbrain_python_library_2.birdbrain_exception import BirdbrainException
+from birdbrain_python_library_2.birdbrain_hummingbird import BirdbrainHummingbird
+from birdbrain_python_library_2.birdbrain_microbit import BirdbrainMicrobit
 
 import pytest
 import time
