@@ -1,8 +1,8 @@
 import pytest
 
-from birdbrain_constant import BirdbrainConstant
-from birdbrain_exception import BirdbrainException
-from birdbrain_request import BirdbrainRequest
+from birdbrain_python_library_2.birdbrain_constant import BirdbrainConstant
+from birdbrain_python_library_2.birdbrain_exception import BirdbrainException
+from birdbrain_python_library_2.birdbrain_request import BirdbrainRequest
 
 
 def test_request_uri():
